@@ -5,7 +5,7 @@ import os
 
 
 class Plotly(InDriver):
-    """ Plot generator lib"""
+    """Plot generator lib"""
 
     __css_base = ".modebar {display: none;} \n.modebar-container {display: none;} "
 
@@ -13,6 +13,7 @@ class Plotly(InDriver):
         html_filename = f"{filename.split('.')[0]}.html"
         html_exist = os.path.exists(html_filename)
         chart.write_html(html_filename)
+        selector = None
         html_map = None
         if css is None:
             css = self.__css_base
@@ -20,6 +21,8 @@ class Plotly(InDriver):
             css = css + self.__css_base
         with open(html_filename) as f:
             html_map = f.read()
+            if html_map.find(" cartesianlayer") != -1:
+                selector = ".cartesianlayer"
             result = html_map.replace(
                 "</head>", f'<style id="naas_css">{css}</style></head>'
             )
@@ -35,8 +38,10 @@ class Plotly(InDriver):
                 "emulateScreenMedia": True,
                 "ignoreHttpsErrors": True,
                 "scrollPage": False,
-                "screenshot": {"type": extension, "selector": ".cartesianlayer"},
+                "screenshot": {"type": extension},
             }
+            if selector:
+                json["screenshot"]["selector"] = selector
             req = requests.post(
                 url=f"{os.environ.get('SCREENSHOT_API', 'http://naas-screenshot:9000')}/api/render",
                 json=json,
@@ -52,7 +57,7 @@ class Plotly(InDriver):
         print(f"Saved as {filename}")
 
     def export(self, chart, filenames, css=None):
-        """ create html export and add css to it"""
+        """create html export and add css to it"""
         if isinstance(filenames, list):
             for filename in filenames:
                 self.__export(chart, filename, css)
@@ -234,7 +239,7 @@ class Plotly(InDriver):
         filter_title="Stock",
         filter_all=False,
     ):
-        """ generate financial_chart """
+        """generate financial_chart"""
         stock_data_copy = stock_data.copy()
         if "Company" not in stock_data_copy:
             stock_data_copy["Company"] = "Company_1"
@@ -335,7 +340,7 @@ class Plotly(InDriver):
     def table(
         self, header_values, cells_values, header_color="rgb(136,233,175)", show=False
     ):
-        """ generate table html """
+        """generate table html"""
 
         fig = go.Figure(
             data=[
