@@ -1,6 +1,6 @@
 from naas_drivers.driver import InDriver, OutDriver
-from .__crud import CRUD
 from requests.auth import HTTPBasicAuth
+from .__crud import CRUD
 import requests
 import json
 import re
@@ -9,35 +9,39 @@ import os
 req_headers = {"Accept": "application/json", "Content-Type": "application/json"}
 
 
-class Me:
+class Me(CRUD):
     base_public_url = None
     endpoint = "me"
-    auth = None
+    key = None
 
     def __init__(self, base_url, auth, endpoint="me"):
         self.base_public_url = base_url
-        self.auth = auth
+        self.key = auth
         self.endpoint = endpoint
 
     def get(self):
+        self.check_connect()
         req = requests.get(
             url=f"{self.base_public_url}/{self.endpoint}",
             headers=req_headers,
-            auth=self.auth,
+            auth=self.key,
             allow_redirects=False,
         )
-        req.raise_for_status()
+        if self.raise_error:
+            req.raise_for_status()
         return req
 
     def update(self, data):
+        self.check_connect()
         req = requests.put(
             url=f"{self.base_public_url}/{self.endpoint}",
             headers=req_headers,
-            auth=self.auth,
+            auth=self.key,
             json=data,
             allow_redirects=False,
         )
-        req.raise_for_status()
+        if self.raise_error:
+            req.raise_for_status()
         return req
 
 
@@ -51,6 +55,7 @@ class CRUDBOB(CRUD):
             params["search"] = json.dumps(search)
         if sort:
             params["sort"] = json.dumps(sort)
+        self.check_connect()
         req = requests.get(
             url=f"{self.base_public_url}/{self.endpoint}",
             params=params,
@@ -58,7 +63,8 @@ class CRUDBOB(CRUD):
             auth=self.auth,
             allow_redirects=False,
         )
-        req.raise_for_status()
+        if self.raise_error:
+            req.raise_for_status()
         return req
 
 
@@ -73,24 +79,28 @@ class SmartTable(CRUDBOB):
         CRUDBOB.__init__(self, base_url, endpoint, auth)
 
     def allowed(self):
+        self.check_connect()
         req = requests.post(
             url=f"{self.base_public_url}/{self.endpoint}/allowed",
             auth=self.auth,
             headers=req_headers,
             allow_redirects=False,
         )
-        req.raise_for_status()
+        if self.raise_error:
+            req.raise_for_status()
         req_json = req.json()
         return True if req_json.allowed else False
 
     def delete_all(self):
+        self.check_connect()
         req = requests.delete(
             url=f"{self.base_public_url}/{self.endpoint}/all",
             auth=self.auth,
             headers=req_headers,
             allow_redirects=False,
         )
-        req.raise_for_status()
+        if self.raise_error:
+            req.raise_for_status()
         return req
 
 
@@ -128,10 +138,14 @@ class Users(CRUDBOB):
 
         # -> role
         if role not in ["user", "admin"]:
-            raise ValueError(f"Role {role} not recognized in Bobapp")
+            error_text = f"Role {role} not recognized in Bobapp"
+            self.print_error(error_text)
+            return None
 
         if not self.validate_email(email):
-            raise ValueError(f"User {email} not valid")
+            error_text = f"User {email} not valid"
+            self.print_error(error_text)
+            return None
 
         # Init user info
         new_user = {
@@ -166,11 +180,15 @@ class Users(CRUDBOB):
         email = email.strip().lower()
 
         if not self.validate_email(email):
-            raise ValueError(f"User {email} not valid")
+            error_text = f"User {email} not valid"
+            self.print_error(error_text)
+            return None
 
         user = self.get_by_email(email)
         if not user:
-            raise ValueError(f"User {email} does not exist in Bobapp")
+            error_text = f"User {email} does not exist in Bobapp"
+            self.print_error(error_text)
+            return None
 
         # Init workspace info
         workspace_param = {
@@ -197,7 +215,9 @@ class Users(CRUDBOB):
                 f"Workspace {workspace_id} : '{workspace_name}' added to user {email}"
             )
         elif user["workspaces"].get(workspace_id, None):
-            print(f"Workspace already exists for user {email}")
+            error_text = f"Workspace already exists for user {email}"
+            self.print_error(error_text)
+            return None
 
         # Set workspace default
         if set_default:
@@ -212,18 +232,24 @@ class Users(CRUDBOB):
         # Check service
         serv_list = ["ftp", "jupyter", "wekan"]
         if serv not in serv_list:
-            raise ValueError(
-                f"Service {serv} does not exist. Please change it to {serv_list}."
+            error_text = (
+                f"Service {serv} does not exist. Please change it to {serv_list}"
             )
+            self.print_error(error_text)
+            return None
 
         # -> email
         email = email.strip().lower()
         if not self.validate_email(email):
-            raise ValueError(f"User {email} not valid")
+            error_text = f"User {email} not valid"
+            self.print_error(error_text)
+            return None
 
         user = self.get_by_email(email)
         if not user:
-            raise ValueError(f"User {email} does not exist in Bobapp")
+            error_text = f"User {email} does not exist in Bobapp"
+            self.print_error(error_text)
+            return None
         # Init service
         service = {
             "authMethod": serv,
@@ -241,14 +267,18 @@ class Users(CRUDBOB):
             self.update(user)
             print(f"Service {serv} Added to user", email)
         else:
-            print(f"Service already exists in Bobapp for {email}")
+            error_text = f"Service already exists in Bobapp for {email}"
+            self.print_error(error_text)
+            return None
 
     def create_service(self, serv, email, password, token):
 
         # Create login
         email = email.strip().lower()
         if not self.validate_email(email):
-            raise ValueError(f"User {email} not valid")
+            error_text = f"User {email} not valid"
+            self.print_error(error_text)
+            return None
 
         login = {
             "username": email,
@@ -258,9 +288,11 @@ class Users(CRUDBOB):
         # Init services
         serv_list = ["ftp", "jupyter"]
         if serv not in serv_list:
-            raise ValueError(
-                f"Service {serv} does not exist. Please change it to {serv_list}."
+            error_text = (
+                f"Service {serv} does not exist. Please change it to {serv_list}"
             )
+            self.print_error(error_text)
+            return None
 
         if serv == "ftp":
             # Variable FTP
@@ -270,7 +302,8 @@ class Users(CRUDBOB):
             # Create user on service ftp
             headers = {"X-Api-Key": AUTH_TOKEN_FTP}
             r = requests.post(URI_FTP, json=login, headers=headers)
-            r.raise_for_status()
+            if self.raise_error:
+                r.raise_for_status()
 
         if serv == "jupyter":
             # Jupyter
@@ -280,7 +313,8 @@ class Users(CRUDBOB):
             # Create user on service jupyter
             headers = {"Authorization": AUTH_TOKEN_JUP}
             r = requests.post(URI_JUP, data=login, headers=headers)
-            r.raise_for_status()
+            if self.raise_error:
+                r.raise_for_status()
 
     def create(
         self,
@@ -333,6 +367,12 @@ class Bobapp(InDriver, OutDriver):
         self.connected = True
         return self
 
+    def raise_for_error(self, raise_error=True):
+        self.raise_error = raise_error
+        self.users.raise_for_error(raise_error)
+        self.workspaces.raise_for_error(raise_error)
+        self.me.raise_for_error(raise_error)
+
     def connect_smarttable(self, database, collection):
         self.check_connect()
         return SmartTable(self.base_public_url, database, collection, self.__auth)
